@@ -27,7 +27,7 @@ protected:
     void resizeEvent(QResizeEvent *resizeEvent) override;
 
 private:
-    KWallet::Wallet     *_wallet;
+    KWallet::Wallet     *_wallet = nullptr;
 };
 
 #endif // AUTHORIZEDAPPLICATIONSTABLE_H
